@@ -75,7 +75,7 @@ class CfnPipeline(
             pipeline_tags=pipeline_tags,
         )
 
-        jsii.create(CfnPipeline, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
